@@ -23,9 +23,9 @@ class ActsRecipe(GitCmakeRecipe):
 
         # Set initial values for parent class and self
         super(ActsRecipe, self).__init__('acts')                        # This name will be used in ejpm commands
-        self.config['branch'] = 'v0.22.01'                              # The branch or tag to be cloned (-b flag)
-        self.config['repo_address'] = 'https://github.com/acts-project/acts.git'    # Repo address
-        self.config['cmake_flags'] = '-DACTS_BUILD_TGEO_PLUGIN=ON -DACTS_BUILD_JSON_PLUGIN=ON'
+        self.config['branch'] = 'v1.2.1'                                # The branch or tag to be cloned (-b flag)
+        self.config['repo_address'] = 'https://github.com/acts-project/acts'    # Repo address
+        self.config['cmake_flags'] = '-DACTS_BUILD_PLUGIN_TGEO=ON'
         self.config['cxx_standard'] = 17
 
     def setup(self, db):
@@ -76,7 +76,7 @@ class ActsRecipe(GitCmakeRecipe):
     # The idea behind is to generate easy to use instructions: 'sudo apt-get install ... ... ... '
     os_dependencies = {
         'required': {
-            'ubuntu': "libboost-dev libeigen3-dev",
+            'ubuntu': "libboost-dev libboost-filesystem-dev libboost-program-options-dev libboost-test-dev libeigen3-dev",
             'centos': "boost-devel eigen3-devel",
             'centos8': "boost-devel eigen3-devel",
         },
